==> ZenTaoALM.12.4.1.int.zbox_32.tar.gz: zbox/app/zentaoep/module/upgrade/ext/lang/zh-cn/bizext.php <==
<?php
$lang->upgrade->fromVersions['12_4_1'] = '12.4.1';

$lang->upgrade->fromVersions['pro1_0']       = 'pro1.0';
$lang->upgrade->fromVersions['pro1_1']       = 'pro1.1';
$lang->upgrade->fromVersions['pro1_1_1']     = 'pro1.1.1';
$lang->upgrade->fromVersions['pro1_2']       = 'pro1.2';
$lang->upgrade->fromVersions['pro1_3']       = 'pro1.3';
$lang->upgrade->fromVersions['pro2_0']       = 'pro2.0';
$lang->upgrade->fromVersions['pro2_0_1']     = 'pro2.0.1';
$lang->upgrade->fromVersions['pro2_1']       = 'pro2.1';
$lang->upgrade->fromVersions['pro2_2_beta']  = 'pro2.2.beta';
$lang->upgrade->fromVersions['pro2_3_beta']  = 'pro2.3.beta';
$lang->upgrade->fromVersions['pro3_0_beta1'] = 'pro3.0.beta1';
$lang->upgrade->fromVersions['pro3_0']       = 'pro3.0';
$lang->upgrade->fromVersions['pro3_1']       = 'pro3.1';
$lang->upgrade->fromVersions['pro3_2']       = 'pro3.2';
$lang->upgrade->fromVersions['pro3_2_1']     = 'pro3.2.1';
$lang->upgrade->fromVersions['pro3_3']       = 'pro3.3';
$lang->upgrade->fromVersions['pro4_0_beta1'] = 'pro4.0.beta1';
$lang->upgrade->fromVersions['pro4_0']       = 'pro4.0';
$lang->upgrade->fromVersions['pro4_1_beta']  = 'pro4.1.beta';
$lang->upgrade->fromVersions['pro4_2']       = 'pro4.2';
$lang->upgrade->fromVersions['pro4_3']       = 'pro4.3';
$lang->upgrade->fromVersions['pro4_4']       = 'pro4.4';
$lang->upgrade->fromVersions['pro4_5']       = 'pro4.5';
$lang->upgrade->fromVersions['pro4_6']       = 'pro4.6';
$lang->upgrade->fromVersions['pro4_7']       = 'pro4.7';
$lang->upgrade->fromVersions['pro4_7_1']     = 'pro4.7.1';
$lang->upgrade->fromVersions['pro5_0']       = 'pro5.0';
$lang->upgrade->fromVersions['pro5_0_1']     = 'pro5.0.1';
$lang->upgrade->fromVersions['pro5_1']       = 'pro5.1';
$lang->upgrade->fromVersions['pro5_1_3']     = 'pro5.1.3';
$lang->upgrade->fromVersions['pro5_2']       = 'pro5.2';
$lang->upgrade->fromVersions['pro5_2_1']     = 'pro5.2.1';
$lang->upgrade->fromVersions['pro5_3']       = 'pro5.3';
$lang->upgrade->fromVersions['pro5_3_1']     = 'pro5.3.1';
$lang->upgrade->fromVersions['pro5_3_2']     = 'pro5.3.2';
$lang->upgrade->fromVersions['pro5_3_3']     = 'pro5.3.3';
$lang->upgrade->fromVersions['pro5_4']       = 'pro5.4';
$lang->upgrade->fromVersions['pro5_4_1']     = 'pro5.4.1';
$lang->upgrade->fromVersions['pro5_5']       = 'pro5.5';
$lang->upgrade->fromVersions['pro5_5_1']     = 'pro5.5.1';
$lang->upgrade->fromVersions['pro6_0_beta']  = 'pro6.0.beta';
$lang->upgrade->fromVersions['pro6_0']       = 'pro6.0';
$lang->upgrade->fromVersions['pro6_0_1']     = 'pro6.0.1';
$lang->upgrade->fromVersions['pro6_1']       = 'pro6.1';
$lang->upgrade->fromVersions['pro6_2']       = 'pro6.2';
$lang->upgrade->fromVersions['pro6_3']       = 'pro6.3';
$lang->upgrade->fromVersions['pro6_3_1']     = 'pro6.3.1';
$lang->upgrade->fromVersions['pro6_4']       = 'pro6.4';
$lang->upgrade->fromVersions['pro6_5']       = 'pro6.5';
$lang->upgrade->fromVersions['pro6_5_1']     = 'pro6.5.1';
$lang->upgrade->fromVersions['pro6_6']       = 'pro6.6';
$lang->upgrade->fromVersions['pro6_6_1']     = 'pro6.6.1';
$lang->upgrade->fromVersions['pro6_7']       = 'pro6.7';
$lang->upgrade->fromVersions['pro6_7_1']     = 'pro6.7.1';
$lang->upgrade->fromVersions['pro6_7_2']     = 'pro6.7.2';
$lang->upgrade->fromVersions['pro6_7_3']     = 'pro6.7.3';
$lang->upgrade->fromVersions['pro7_0_beta']  = 'pro7.0.beta';
$lang->upgrade->fromVersions['pro7_1']       = 'pro7.1';
$lang->upgrade->fromVersions['pro7_2']       = 'pro7.2';
$lang->upgrade->fromVersions['pro7_3']       = 'pro7.3';
$lang->upgrade->fromVersions['pro7_4']       = 'pro7.4';
$lang->upgrade->fromVersions['pro7_5']       = 'pro7.5';
$lang->upgrade->fromVersions['pro7_5_1']     = 'pro7.5.1';
$lang->upgrade->fromVersions['pro8_0']       = 'pro8.0';
$lang->upgrade->fromVersions['pro8_1']       = 'pro8.1';
$lang->upgrade->fromVersions['pro8_2']       = 'pro8.2';
$lang->upgrade->fromVersions['pro8_3']       = 'pro8.3';
$lang->upgrade->fromVersions['pro8_3_1']     = 'pro8.3.1';
$lang->upgrade->fromVersions['pro8_4']       = 'pro8.4';
$lang->upgrade->fromVersions['pro8_5']       = 'pro8.5';
$lang->upgrade->fromVersions['pro8_5_1']     = 'pro8.5.1';
$lang->upgrade->fromVersions['pro8_5_2']     = 'pro8.5.2';
$lang->upgrade->fromVersions['pro8_5_3']     = 'pro8.5.3';
$lang->upgrade->fromVersions['pro8_6']       = 'pro8.6';
$lang->upgrade->fromVersions['pro8_7']       = 'pro8.7';
$lang->upgrade->fromVersions['pro8_7_1']     = 'pro8.7.1';
$lang->upgrade->fromVersions['pro8_8']       = 'pro8.8';
$lang->upgrade->fromVersions['pro8_8_1']     = 'pro8.8.1';
$lang->upgrade->fromVersions['pro8_8_2']     = 'pro8.8.2';
$lang->upgrade->fromVersions['pro8_8_3']     = 'pro8.8.3';
$lang->upgrade->fromVersions['pro8_9']       = 'pro8.9';

$lang->upgrade->needBuild4Add    = '本次升级新增全文检索功能，需要创建索引。';
$lang->upgrade->needBuild4Adjust = '本次升级全文检索功能有调整，需要创建索引。';
$lang->upgrade->buildIndex       = '创建索引';

==> ZenTaoALM.12.5.2.int.zbox_32.tar.gz: zbox/app/zentaoep/module/upgrade/ext/lang/zh-cn/bizext.php <==
<?php
$lang->upgrade->fromVersions['12_5_2'] = '12.5.2';

$lang->upgrade->fromVersions['pro1_0']       = 'pro1.0';
$lang->upgrade->fromVersions['pro1_1']       = 'pro1.1';
$lang->upgrade->fromVersions['pro1_1_1']     = 'pro1.1.1';
$lang->upgrade->fromVersions['pro1_2']       = 'pro1.2';
$lang->upgrade->fromVersions['pro1_3']       = 'pro1.3';
$lang->upgrade->fromVersions['pro2_0']       = 'pro2.0';
$lang->upgrade->fromVersions['pro2_0_1']     = 'pro2.0.1';
$lang->upgrade->fromVersions['pro2_1']       = 'pro2.1';
$lang->upgrade->fromVersions['pro2_2_beta']  = 'pro2.2.beta';
$lang->upgrade->fromVersions['pro2_3_beta']  = 'pro2.3.beta';
$lang->upgrade->fromVersions['pro3_0_beta1'] = 'pro3.0.beta1';
$lang->upgrade->fromVersions['pro3_0']       = 'pro3.0';
$lang->upgrade->fromVersions['pro3_1']       = 'pro3.1';
$lang->upgrade->fromVersions['pro3_2']       = 'pro3.2';
$lang->upgrade->fromVersions['pro3_2_1']     = 'pro3.2.1';
$lang->upgrade->fromVersions['pro3_3']       = 'pro3.3';
$lang->upgrade->fromVersions['pro4_0_beta1'] = 'pro4.0.beta1';
$lang->upgrade->fromVersions['pro4_0']       = 'pro4.0';
$lang->upgrade->fromVersions['pro4_1_beta']  = 'pro4.1.beta';
$lang->upgrade->fromVersions['pro4_2']       = 'pro4.2';
$lang->upgrade->fromVersions['pro4_3']       = 'pro4.3';
$lang->upgrade->fromVersions['pro4_4']       = 'pro4.4';
$lang->upgrade->fromVersions['pro4_5']       = 'pro4.5';
$lang->upgrade->fromVersions['pro4_6']       = 'pro4.6';
$lang->upgrade->fromVersions['pro4_7']       = 'pro4.7';
$lang->upgrade->fromVersions['pro4_7_1']     = 'pro4.7.1';
$lang->upgrade->fromVersions['pro5_0']       = 'pro5.0';
$lang->upgrade->fromVersions['pro5_0_1']     = 'pro5.0.1';
$lang->upgrade->fromVersions['pro5_1']       = 'pro5.1';
$lang->upgrade->fromVersions['pro5_1_3']     = 'pro5.1.3';
$lang->upgrade->fromVersions['pro5_2']       = 'pro5.2';
$lang->upgrade->fromVersions['pro5_2_1']     = 'pro5.2.1';
$lang->upgrade->fromVersions['pro5_3']       = 'pro5.3';
$lang->upgrade->fromVersions['pro5_3_1']     = 'pro5.3.1';
$lang->upgrade->fromVersions['pro5_3_2']     = 'pro5.3.2';
$lang->upgrade->fromVersions['pro5_3_3']     = 'pro5.3.3';
$lang->upgrade->fromVersions['pro5_4']       = 'pro5.4';
$lang->upgrade->fromVersions['pro5_4_1']     = 'pro5.4.1';
$lang->upgrade->fromVersions['pro5_5']       = 'pro5.5';
$lang->upgrade->fromVersions['pro5_5_1']     = 'pro5.5.1';
$lang->upgrade->fromVersions['pro6_0_beta']  = 'pro6.0.beta';
$lang->upgrade->fromVersions['pro6_0']       = 'pro6.0';
$lang->upgrade->fromVersions['pro6_0_1']     = 'pro6.0.1';
$lang->upgrade->fromVersions['pro6_1']       = 'pro6.1';
$lang->upgrade->fromVersions['pro6_2']       = 'pro6.2';
$lang->upgrade->fromVersions['pro6_3']       = 'pro6.3';
$lang->upgrade->fromVersions['pro6_3_1']     = 'pro6.3.1';
$lang->upgrade->fromVersions['pro6_4']       = 'pro6.4';
$lang->upgrade->fromVersions['pro6_5']       = 'pro6.5';
$lang->upgrade->fromVersions['pro6_5_1']     = 'pro6.5.1';
$lang->upgrade->fromVersions['pro6_6']       = 'pro6.6';
$lang->upgrade->fromVersions['pro6_6_1']     = 'pro6.6.1';
$lang->upgrade->fromVersions['pro6_7']       = 'pro6.7';
$lang->upgrade->fromVersions['pro6_7_1']     = 'pro6.7.1';
$lang->upgrade->fromVersions['pro6_7_2']     = 'pro6.7.2';
$lang->upgrade->fromVersions['pro6_7_3']     = 'pro6.7.3';
$lang->upgrade->fromVersions['pro7_0_beta']  = 'pro7.0.beta';
$lang->upgrade->fromVersions['pro7_1']       = 'pro7.1';
$lang->upgrade->fromVersions['pro7_2']       = 'pro7.2';
$lang->upgrade->fromVersions['pro7_3']       = 'pro7.3';
$lang->upgrade->fromVersions['pro7_4']       = 'pro7.4';
$lang->upgrade->fromVersions['pro7_5']       = 'pro7.5';
$lang->upgrade->fromVersions['pro7_5_1']     = 'pro7.5.1';
$lang->upgrade->fromVersions['pro8_0']       = 'pro8.0';
$lang->upgrade->fromVersions['pro8_1']       = 'pro8.1';
$lang->upgrade->fromVersions['pro8_2']       = 'pro8.2';
$lang->upgrade->fromVersions['pro8_3']       = 'pro8.3';
$lang->upgrade->fromVersions['pro8_3_1']     = 'pro8.3.1';
$lang->upgrade->fromVersions['pro8_4']       = 'pro8.4';
$lang->upgrade->fromVersions['pro8_5']       = 'pro8.5';
$lang->upgrade->fromVersions['pro8_5_1']     = 'pro8.5.1';
$lang->upgrade->fromVersions['pro8_5_2']     = 'pro8.5.2';
$lang->upgrade->fromVersions['pro8_5_3']     = 'pro8.5.3';
$lang->upgrade->fromVersions['pro8_6']       = 'pro8.6';
$lang->upgrade->fromVersions['pro8_7']       = 'pro8.7';
$lang->upgrade->fromVersions['pro8_7_1']     = 'pro8.7.1';
$lang->upgrade->fromVersions['pro8_8']       = 'pro8.8';
$lang->upgrade->fromVersions['pro8_8_1']     = 'pro8.8.1';
$lang->upgrade->fromVersions['pro8_8_2']     = 'pro8.8.2';
$lang->upgrade->fromVersions['pro8_8_3']     = 'pro8.8.3';
$lang->upgrade->fromVersions['pro8_9']       = 'pro8.9';
$lang->upgrade->fromVersions['pro8_9_1']     = 'pro8.9.1';
$lang->upgrade->fromVersions['pro8_9_2']     = 'pro8.9.2';
$lang->upgrade->fromVersions['pro8_9_3']     = 'pro8.9.3';
$lang->upgrade->fromVersions['pro8_9_4']     = 'pro8.9.4';
$lang->upgrade->fromVersions['pro9_0']       = 'pro9.0';
$lang->upgrade->fromVersions['pro9_0_1']     = 'pro9.0.1';

$lang->upgrade->needBuild4Add    = '本次升级新增全文检索功能，需要创建索引。';
$lang->upgrade->needBuild4Adjust = '本次升级全文检索功能有调整，需要创建索引。';
$lang->upgrade->buildIndex       = '创建索引';
